"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.App = void 0;
const express_1 = __importDefault(require("express"));
const cors_1 = __importDefault(require("cors"));
const util_1 = require("./util");
const controller_1 = require("./controller");
const logger_1 = __importDefault(require("./util/logger"));
const os_1 = __importDefault(require("os"));
const sqlite_client_1 = require("./model/sqlite-client");
const server_status_task_1 = require("./tasks/server-status-task");
const task_service_1 = require("./service/task-service");
const port = process.env.LOOPER_PORT ? parseInt(process.env.LOOPER_PORT) : 8080;
class App {
    start() {
        sqlite_client_1.sqliteClient.init();
        const app = (0, express_1.default)();
        app.use(express_1.default.json());
        if (process.env.LOOPER_DEBUG) {
            app.use((0, cors_1.default)({
                origin: '*'
            }));
            app.use((req, res, next) => {
                logger_1.default.debug(req.method + ' ' + req.originalUrl + new Date().toString());
                next();
            });
        }
        (0, controller_1.createRoutes)(app);
        this.app = app;
        app.use(express_1.default.static(`${util_1.pathUtil.getAppRootPath()}/public`));
        this.server = app.listen(port, () => {
            logger_1.default.info(`Server started! OS: ${os_1.default.type()}`);
            server_status_task_1.serverStatusTask.start();
            task_service_1.mediaTaskService.start();
        });
        process.on('exit', (code) => {
            logger_1.default.info(`Exiting with code ${code}`);
            server_status_task_1.serverStatusTask.stop();
            process.exit(code);
        });
        process.on('SIGTERM', (code) => {
            logger_1.default.warn(`Exiting with code ${code}`);
            process.exit(code);
        });
        process.on('unhandledRejection', (err) => {
            logger_1.default.error('catching an unhandledRejection!');
            logger_1.default.error(err);
        });
        process.on('uncaughtException', (err) => {
            logger_1.default.error('catching an uncaughtException!');
            logger_1.default.error(err);
        });
    }
}
exports.App = App;
exports.default = new App();
