"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataRoute = void 0;
const express_1 = require("express");
const _1 = require(".");
const data_service_1 = require("../service/data-service");
function dataRoute() {
    const route = (0, express_1.Router)();
    route.get(`/backup`, (0, _1.queryValidator)(['key']), _1.requestAuthentication, (req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            const query = req.query;
            res.send(yield data_service_1.dataService.downloadBackup(query.key));
        }
        catch (e) {
            next(e);
        }
    }));
    route.get(`/backup/list`, _1.requestAuthentication, (req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            const query = req.query;
            const data = yield data_service_1.dataService.listBackups(query.continuationToken);
            res.send(data);
        }
        catch (e) {
            next(e);
        }
    }));
    route.post(`/backup`, _1.requestAuthentication, (req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            yield data_service_1.dataService.backup();
            res.sendStatus(204);
        }
        catch (e) {
            next(e);
        }
    }));
    route.delete(`/backup/:key`, _1.requestAuthentication, (req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            yield data_service_1.dataService.deleteBackup(req.params.key);
            res.sendStatus(204);
        }
        catch (e) {
            next(e);
        }
    }));
    route.put(`/backup/:key/sync`, _1.requestAuthentication, (req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            res.send(yield data_service_1.dataService.syncBackup(req.params.key));
        }
        catch (e) {
            next(e);
        }
    }));
    route.put(`/storage/sync`, _1.requestAuthentication, (req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            res.send(yield data_service_1.dataService.syncStorage());
        }
        catch (e) {
            next(e);
        }
    }));
    return route;
}
exports.dataRoute = dataRoute;
