"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.localhostValidation = exports.getPagination = exports.requestAuthentication = exports.createRoutes = exports.bodyValidator = exports.queryValidator = void 0;
const yup = __importStar(require("yup"));
const authentication_service_1 = require("../service/authentication-service");
const constants_1 = require("../util/constants");
const auth_controller_1 = require("./auth-controller");
const server_status_controller_1 = require("./server-status-controller");
const sqlite_client_1 = require("../model/sqlite-client");
const media_controller_1 = require("./media-controller");
const media_upload_controller_1 = require("./media-upload-controller");
const storage_controller_1 = require("./storage-controller");
const output_controller_1 = require("./output-controller");
const playlist_controller_1 = require("./playlist-controller");
const task_controller_1 = require("./task-controller");
const streaming_controller_1 = require("./streaming-controller");
const data_controller_1 = require("./data-controller");
const localhostAddress = ["127.0.0.1", "::1"];
const createSchema = (schema) => {
    return yup.object().shape(schema);
};
const errorHandler = (err, _req, res, _next) => {
    if ("status" in err) {
        res.status(err.status).send({
            message: err.message,
        });
    }
    else {
        console.log(err);
        res.status(constants_1.ERROR.UNEXPECTED_ERROR.status).send({
            message: constants_1.ERROR.UNEXPECTED_ERROR.message,
        });
    }
};
const queryValidator = (requiredAttributes) => {
    return (req, _res, next) => __awaiter(void 0, void 0, void 0, function* () {
        const query = req.query;
        let valid = true;
        for (let i = 0; i < requiredAttributes.length; i++) {
            if (!query.hasOwnProperty(requiredAttributes[i])) {
                valid = false;
                break;
            }
        }
        if (valid) {
            next();
        }
        else {
            next(constants_1.ERROR.INVALID_QUERY);
        }
    });
};
exports.queryValidator = queryValidator;
const bodyValidator = (schemas) => {
    const bodySchema = createSchema(schemas.body);
    return (req, _res, next) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            yield bodySchema.validate(req.body);
            next();
        }
        catch (e) {
            next(constants_1.ERROR.INVALID_BODY);
        }
    });
};
exports.bodyValidator = bodyValidator;
function createRoutes(express) {
    express.use("/auth", (0, auth_controller_1.authRoute)());
    express.use("/data", (0, data_controller_1.dataRoute)());
    express.use("/server", (0, server_status_controller_1.serverStatusRoute)());
    express.use("/media", (0, media_controller_1.mediaRoute)());
    express.use("/upload", (0, media_upload_controller_1.mediaUploadRoute)());
    express.use("/storage", (0, storage_controller_1.storageRoute)());
    express.use("/output", (0, output_controller_1.outputRoute)());
    express.use("/playlist", (0, playlist_controller_1.playlistRoute)());
    express.use("/task", (0, task_controller_1.taskRoute)());
    express.use("/streaming", (0, streaming_controller_1.streamingRoute)());
    express.use(errorHandler);
}
exports.createRoutes = createRoutes;
function requestAuthentication(req, res, next) {
    const token = req.headers.authorization;
    if (token && authentication_service_1.authenticationToken.verify(token)) {
        next();
    }
    else {
        next(constants_1.ERROR.UNAUTHORIZED);
    }
}
exports.requestAuthentication = requestAuthentication;
function getPagination(req) {
    const query = req.query;
    if (query) {
        const nSize = query.size ? parseInt(query.size) : 10;
        const nPage = query.page ? parseInt(query.page) : 0;
        return new sqlite_client_1.Pagination(nSize, nPage);
    }
    else {
        return new sqlite_client_1.Pagination();
    }
}
exports.getPagination = getPagination;
function localhostValidation(req, res, next) {
    if ((req.socket.remoteAddress &&
        localhostAddress.includes(req.socket.remoteAddress)) ||
        req.socket.localAddress === req.socket.localAddress)
        next();
    else
        res.status(constants_1.ERROR.UNAUTHORIZED.status).send(constants_1.ERROR.UNAUTHORIZED);
}
exports.localhostValidation = localhostValidation;
