"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseModel = void 0;
const sqlite_client_1 = require("./sqlite-client");
class BaseModel {
    constructor(table, sqlite = sqlite_client_1.sqliteClient) {
        this.sqlite = sqlite;
        this.table = table;
    }
    create(data) {
        data.id = this.sqlite.createId();
        this.insert(data);
        return data.id;
    }
    insert(data) {
        this.sqlite.insertOne(this.table, data);
    }
    update(data, id) {
        this.sqlite.update(this.table, data, { id });
    }
    delete(id) {
        this.sqlite.deleteById(this.table, id);
    }
    list(pagination) {
        return this.sqlite.selectAll(this.table, pagination);
    }
    query(query, params) {
        return this.sqlite.runSelectQuery(query, params);
    }
    queryFirst(query, params) {
        const rows = this.query(query, params);
        if (rows && rows.length > 0) {
            return rows[0];
        }
        return undefined;
    }
    findByString(params, pagination) {
        return this.sqlite.findByLikeOr(this.table, params, pagination);
    }
    findByLike(pagination, str) {
        const options = {
            pagination: pagination,
        };
        if (str) {
            options.params = { name: `%${str}%` };
        }
        const count = this.countByLikeOr(options.params);
        const records = this.findByLikeOr(options);
        records.sort((a, b) => a.name.localeCompare(b.name));
        return { count, pagination, records };
    }
    findByLikeOr(options) {
        if (options.params) {
            return this.findByString(options.params, options.pagination);
        }
        else {
            return this.list(options.pagination);
        }
    }
    findById(id) {
        return this.sqlite.findById(this.table, id);
    }
    countByLikeOr(params) {
        return this.sqlite.countByLikeOr(this.table, params);
    }
    count(params) {
        return this.sqlite.count(this.table, params);
    }
}
exports.BaseModel = BaseModel;
