"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configModel = exports.ConfigModel = exports.StorageProviderEnum = void 0;
const base_model_1 = require("./base-model");
const sqlite_client_1 = require("./sqlite-client");
const CONFIG_KEY = {
    AUTHENTICATION_KEY: "authentication_key",
    STORAGE_SETTINGS: "storage_settings",
    TRANSCODER_SETTINGS: "transcoder_settings",
    TASKS_SETTINGS: "tasks_settings",
};
var StorageProviderEnum;
(function (StorageProviderEnum) {
    StorageProviderEnum["AWS"] = "AWS";
})(StorageProviderEnum || (exports.StorageProviderEnum = StorageProviderEnum = {}));
class ConfigModel extends base_model_1.BaseModel {
    constructor(sqlite = sqlite_client_1.sqliteClient) {
        super("config", sqlite);
    }
    getTranscoderSettings() {
        return this.findByKey(CONFIG_KEY.TRANSCODER_SETTINGS);
    }
    setTranscoderSettings(settings) {
        this.update({ value: JSON.stringify(settings) }, CONFIG_KEY.TRANSCODER_SETTINGS);
    }
    getSecretKey() {
        const row = this.findById(CONFIG_KEY.AUTHENTICATION_KEY);
        return row.value;
    }
    setSecretKey(key) {
        this.update({ value: key }, CONFIG_KEY.AUTHENTICATION_KEY);
    }
    getStorageSettings() {
        return this.findByKey(CONFIG_KEY.STORAGE_SETTINGS);
    }
    setStorageSettings(settings) {
        this.update({ value: JSON.stringify(settings) }, CONFIG_KEY.STORAGE_SETTINGS);
    }
    getTasksSettings() {
        return this.findByKey(CONFIG_KEY.TASKS_SETTINGS);
    }
    setTasksSettings(settings) {
        this.update({ value: JSON.stringify(settings) }, CONFIG_KEY.TASKS_SETTINGS);
    }
    findByKey(key) {
        const row = this.findById(key);
        return JSON.parse(row.value);
    }
}
exports.ConfigModel = ConfigModel;
exports.configModel = new ConfigModel();
