"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mediaModel = exports.MediaModel = exports.MediaStateEnum = void 0;
const base_model_1 = require("./base-model");
const sqlite_client_1 = require("./sqlite-client");
const GET_TOTAL_DURATION_AND_SIZE = `
  SELECT SUM(duration) as duration
  , SUM(size) as size
  , SUM(CASE state WHEN 'UPLOADING' THEN 1 ELSE 0 END) as total_upload
  , SUM(CASE state WHEN 'UPLOAD_FAILED' THEN 1 ELSE 0 END) as total_upload_failed
  , SUM(CASE state WHEN 'UNDER_ANALYSIS' THEN 1 ELSE 0 END) as total_under_analysis
  , SUM(CASE state WHEN 'ANALYSIS_FAIL' THEN 1 ELSE 0 END) as total_analysis_fail
  , SUM(CASE state WHEN 'READY' THEN 1 ELSE 0 END) as total_ready
  , COUNT(id) as count_medias
  FROM media
`;
const FIND_FIRST_BY_SEND_TO_TRANSCODER = "SELECT * FROM media m WHERE m.send_to_transcoder = @send_to_transcoder AND state = @state LIMIT 1";
const FIND_FIRST_BY_STATE = "SELECT * FROM media WHERE state = @state LIMIT 1";
const FIND_FIRST_WITHOUT_THUMBNAIL = "SELECT * FROM media WHERE state = 'READY' AND thumbnail_key is NULL LIMIT 1";
var MediaStateEnum;
(function (MediaStateEnum) {
    MediaStateEnum["UPLOAD"] = "UPLOADING";
    MediaStateEnum["UNDER_ANALYSIS"] = "UNDER_ANALYSIS";
    MediaStateEnum["ANALYSIS_FAIL"] = "ANALYSIS_FAIL";
    MediaStateEnum["READY"] = "READY";
    MediaStateEnum["UPLOAD_FAILED"] = "UPLOAD_FAILED";
})(MediaStateEnum || (exports.MediaStateEnum = MediaStateEnum = {}));
class MediaModel extends base_model_1.BaseModel {
    constructor(sqlite = sqlite_client_1.sqliteClient) {
        super('media', sqlite);
    }
    findFirstBySendToTranscoder() {
        return this.queryFirst(FIND_FIRST_BY_SEND_TO_TRANSCODER, { send_to_transcoder: 1, state: MediaStateEnum.READY });
    }
    createMedia(media) {
        this.insert(media);
    }
    getTotalDurationAndSize() {
        return this.queryFirst(GET_TOTAL_DURATION_AND_SIZE);
    }
    findFirstByState(state) {
        return this.queryFirst(FIND_FIRST_BY_STATE, { state });
    }
    findFirstWithoutThumbnail() {
        return this.queryFirst(FIND_FIRST_WITHOUT_THUMBNAIL);
    }
    findByNameAndState(pagination, name, state) {
        const count = this.countByNameAndStatus(name, state);
        const records = this.findByNameAndStatus(pagination, name, state);
        return { count, pagination, records };
    }
    countByNameAndStatus(name, state) {
        const query = `SELECT count(1) as count FROM media m WHERE m.name LIKE @name ${state ? 'AND m.state = @state' : ''}`;
        const params = {
            name: name ? `%${name}%` : '%'
        };
        if (state) {
            params.state = state;
        }
        const rows = this.sqlite.runSelectQuery(query, params);
        return rows[0].count;
    }
    findByNameAndStatus(pagination, name, state) {
        const query = `SELECT * FROM media m WHERE m.name LIKE @name ${state ? 'AND m.state = @state' : ''}  LIMIT @index, @size `;
        const params = {
            name: name ? `%${name}%` : '%'
        };
        if (state) {
            params.state = state;
        }
        if (pagination) {
            params.size = pagination.size;
            params.index = pagination.getQueryStartIndex();
        }
        return this.sqlite.runSelectQuery(query, params);
    }
    findAllByMediaIdList(ids) {
        if (!Array.isArray(ids) || ids.length == 0) {
            return [];
        }
        const params = {};
        let idParamList = '';
        ids.forEach((id, idx) => {
            const paramName = `id${idx}`;
            params[paramName] = id;
            idParamList += `@id${idx}`;
            if (idx < ids.length - 1)
                idParamList += ', ';
        });
        const sql = `SELECT * FROM media WHERE id IN (${idParamList})`;
        return this.sqlite.select(sql, params);
    }
}
exports.MediaModel = MediaModel;
exports.mediaModel = new MediaModel();
