"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ffmpegModule = exports.FfmpegModule = void 0;
const child_process_1 = require("child_process");
const util_1 = require("../util");
const config_model_1 = require("../model/config-model");
class FfmpegModule {
    constructor(configM = config_model_1.configModel) {
        this.configModel = configM;
    }
    transcode({ input, output, useSystemFFmpeg, onComplete, }) {
        this.spawnFfmpeg(this.createForkParamsList({
            ffmpegParams: this.createFFmpegParamsList(input, output),
            useSystemFFmpeg,
        }), onComplete);
    }
    createFFmpegParamsList(input, output) {
        const config = this.configModel.getTranscoderSettings();
        return [
            "-y",
            "-hide_banner",
            "-v",
            "error",
            "-probesize",
            "10M",
            "-analyzeduration",
            "10M",
            "-i",
            input,
            "-preset",
            "fast",
            "-profile:v",
            "high",
            "-c:v",
            "libx264",
            "-c:a",
            "aac",
            "-crf",
            config.crf,
            //"-b:v", config.video_bitrate,
            "-b:a",
            config.audio_bitrate,
            "-ar",
            config.audio_sample_rate,
            "-pix_fmt",
            "yuv420p",
            "-maxrate",
            config.max_rate,
            "-bufsize",
            config.bufsize,
            "-force_key_frames",
            "expr:gte(t,n_forced*4)",
            //            "-g", "58",
            //            "-keyint_min", "58",
            "-bf",
            "3",
            "-b_strategy",
            "2",
            "-sc_threshold",
            "0",
            "-refs",
            "10",
            "-vf",
            `fps=${config.fps},scale=iw*sar:ih,scale=${config.scale}:trunc(ow/a/2)*2`,
            "-strict",
            "-2",
            "-f",
            "mp4",
            output,
        ];
    }
    thumbnail({ input, output, useSystemFFmpeg = false, onComplete, }) {
        this.spawnFfmpeg(this.createForkParamsList({
            ffmpegParams: this.createThumbnailParamsList(input, output),
            useSystemFFmpeg,
        }), onComplete);
    }
    createThumbnailParamsList(input, output) {
        return [
            "-y",
            "-hide_banner",
            "-v",
            "error",
            "-probesize",
            "10M",
            "-analyzeduration",
            "10M",
            "-i",
            input,
            "-an",
            "-vf",
            `scale=iw*sar:ih,scale=320:trunc(ow/a/2)*2`,
            "-vframes",
            "1",
            output,
        ];
    }
    spawnFfmpeg(params, onComplete) {
        const child = (0, child_process_1.fork)(`${util_1.pathUtil.getAppRootPath()}/ffmpeg.js`, params);
        child.on("error", (err) => console.log(err));
        child.on("close", (code) => {
            if (code !== 0) {
                onComplete(code);
            }
            else {
                onComplete();
            }
        });
    }
    createForkParamsList({ ffmpegParams, useSystemFFmpeg, }) {
        const params = [];
        params.push(JSON.stringify(ffmpegParams));
        params.push(useSystemFFmpeg.toString());
        if (process.env.LOOPER_DEBUG) {
            params.push("true");
        }
        return params;
    }
}
exports.FfmpegModule = FfmpegModule;
exports.ffmpegModule = new FfmpegModule();
