"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storageModule = exports.StorageModule = void 0;
const config_model_1 = require("../model/config-model");
const s3_util_v2_1 = require("../util/s3-util-v2");
const constants_1 = require("../util/constants");
class StorageModule {
    constructor(configM = config_model_1.configModel) {
        this.configModel = configM;
    }
    list(prefix, maxKeys, continuationToken) {
        const s3 = this.getStorageInstance();
        return s3.list(prefix, maxKeys, continuationToken);
    }
    download(outputPath, objectKey) {
        const s3Util = this.getStorageInstance();
        return s3Util.download(outputPath, objectKey);
    }
    getSignedUrl(objectKey) {
        const s3Util = this.getStorageInstance();
        return s3Util.getPresignedUrl(objectKey, 300);
    }
    upload(objectKey, contentType, filePath) {
        const s3Util = this.getStorageInstance();
        return s3Util.uploadMultipart(objectKey, contentType, filePath);
    }
    createMultipartUpload(objectKey, contentType) {
        const s3Util = this.getStorageInstance();
        return s3Util.initMultipartUpload(objectKey, contentType);
    }
    getPresignedUploadPartUrl(uploadId, key, index) {
        const s3Util = this.getStorageInstance();
        return s3Util.getPresignedUploadPartUrl(uploadId, key, index);
    }
    completeMultiPartUpload(objectKey, uploadId, uploadPartResults) {
        const s3Util = this.getStorageInstance();
        return s3Util.completeMultipartUpload(objectKey, uploadId, uploadPartResults);
    }
    abortMultiPartUpload(objectKey, uploadId) {
        const s3Util = this.getStorageInstance();
        try {
            s3Util.abortMultipartUpload(objectKey, uploadId);
        }
        catch (e) { }
    }
    getSinglePartUpload(Key, contentType) {
        const s3Util = this.getStorageInstance();
        return s3Util.getUploadPresignedUrl(Key, contentType);
    }
    delete(objectKey) {
        const s3Util = this.getStorageInstance();
        return s3Util.delete(objectKey);
    }
    getStorageInstance() {
        if (!this.s3Util) {
            const settings = this.configModel.getStorageSettings();
            if (!settings.isConfigured || !settings.aws)
                throw constants_1.ERROR.STORAGE_NOT_CONFIGURED;
            const options = {
                bucket: settings.aws.bucket,
                region: settings.aws.region,
            };
            if (settings.aws.awsKey) {
                options.credentials = {
                    accessKeyId: settings.aws.awsKey,
                    secretAccessKey: settings.aws.awsSecret,
                };
            }
            this.s3Util = new s3_util_v2_1.S3UtilV2(options);
        }
        return this.s3Util;
    }
}
exports.StorageModule = StorageModule;
exports.storageModule = new StorageModule();
