"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.playlistServiceUtil = exports.PlaylistServiceUtil = void 0;
const media_model_1 = require("../model/media-model");
const playlist_model_1 = require("../model/playlist-model");
const storage_module_1 = require("../module/storage-module");
const constants_1 = require("../util/constants");
class PlaylistServiceUtil {
    constructor(playlistM = playlist_model_1.playlistModel, mediaM = media_model_1.mediaModel, storageM = storage_module_1.storageModule) {
        this.playlistModel = playlistM;
        this.mediaModel = mediaM;
        this.storageModule = storageM;
    }
    findById(id) {
        const playlist = this.playlistModel.findById(id);
        if (!playlist)
            throw constants_1.ERROR.NOT_FOUND;
        return this.fetchMedias(playlist);
    }
    fetchMedias(playlist) {
        return __awaiter(this, void 0, void 0, function* () {
            const breakPlaylist = playlist.break_playlist
                ? this.playlistModel.findById(playlist.break_playlist)
                : undefined;
            const medias = this.findAllMediasFromPlaylist(playlist, breakPlaylist);
            yield this.fetchThumbnails(medias);
            const opening_media_data = this.findMediaByIdFromList(medias, playlist.opening_media);
            const closing_media_data = this.findMediaByIdFromList(medias, playlist.closing_media);
            const playListMedias = this.fetchMediasByMediaListId(medias, playlist.medias);
            const break_playlist_data = breakPlaylist
                ? Object.assign(Object.assign({}, breakPlaylist), { medias: this.fetchMediasByMediaListId(medias, breakPlaylist.medias) }) : undefined;
            return Object.assign(Object.assign({}, playlist), { opening_media_data,
                closing_media_data,
                break_playlist_data, medias: playListMedias });
        });
    }
    findAllMediasFromPlaylist(playlist, breakPlaylist) {
        const mediaIds = playlist.medias ? [...playlist.medias] : [];
        if (playlist.opening_media) {
            mediaIds.push(playlist.opening_media);
        }
        if (playlist.closing_media) {
            mediaIds.push(playlist.closing_media);
        }
        if (breakPlaylist && breakPlaylist.medias) {
            mediaIds.push(...breakPlaylist.medias);
        }
        return this.mediaModel.findAllByMediaIdList(mediaIds);
    }
    fetchThumbnails(medias) {
        return __awaiter(this, void 0, void 0, function* () {
            if (medias) {
                for (const media of medias) {
                    if (media.thumbnail_key && media.thumbnail_key !== "none") {
                        media.thumbnail = yield this.storageModule.getSignedUrl(media.thumbnail_key);
                    }
                }
            }
        });
    }
    findMediaByIdFromList(medias, id) {
        if (id)
            return medias.find((media) => media.id === id);
    }
    fetchMediasByMediaListId(mediaList, mediaIds) {
        const medias = [];
        if (mediaIds) {
            mediaIds.forEach((id) => {
                const founded = this.findMediaByIdFromList(mediaList, id);
                if (founded) {
                    medias.push(founded);
                }
            });
        }
        return medias;
    }
}
exports.PlaylistServiceUtil = PlaylistServiceUtil;
exports.playlistServiceUtil = new PlaylistServiceUtil();
