"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.playlistService = exports.PlaylistService = void 0;
const playlist_model_1 = require("../model/playlist-model");
const playlist_service_util_1 = require("./playlist-service-util");
class PlaylistService {
    constructor(pPlaylistModel = playlist_model_1.playlistModel, pPlaylistServiceUtil = playlist_service_util_1.playlistServiceUtil) {
        this.playlistModel = pPlaylistModel;
        this.playlistServiceUtil = pPlaylistServiceUtil;
    }
    all() {
        const rows = this.playlistModel.findAll();
        return this.fetchMediasAndSort(rows);
    }
    findAllByName(pagination, name) {
        return __awaiter(this, void 0, void 0, function* () {
            const playlists = this.playlistModel.findByLike(pagination, name);
            return Object.assign(Object.assign({}, playlists), { records: yield this.fetchMediasAndSort(playlists.records) });
        });
    }
    findById(id) {
        return this.playlistServiceUtil.findById(id);
    }
    fetchMediasAndSort(playlists) {
        return __awaiter(this, void 0, void 0, function* () {
            const fetchedPls = [];
            if (playlists) {
                for (const pl of playlists) {
                    fetchedPls.push(yield this.playlistServiceUtil.fetchMedias(pl));
                }
                fetchedPls.sort((a, b) => a.name.localeCompare(b.name));
            }
            return fetchedPls;
        });
    }
}
exports.PlaylistService = PlaylistService;
exports.playlistService = new PlaylistService();
