"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ffprobeTask = exports.FfprobeTask = void 0;
const util_1 = require("../util");
const ffprobe_module_1 = require("../module/ffprobe-module");
const console_module_1 = require("../module/console-module");
const media_model_1 = require("../model/media-model");
const media_model_2 = require("../model/media-model");
const storage_module_1 = require("../module/storage-module");
class FfprobeTask extends console_module_1.ConsoleModule {
    constructor(ffprobeM = ffprobe_module_1.ffprobeModule, mediaM = media_model_2.mediaModel, storageM = storage_module_1.storageModule) {
        super();
        this.ffprobeModule = ffprobeM;
        this.mediaModel = mediaM;
        this.storageModule = storageM;
    }
    run(settings, onComplete) {
        return __awaiter(this, void 0, void 0, function* () {
            const media = this.mediaModel.findFirstByState(media_model_1.MediaStateEnum.UNDER_ANALYSIS);
            if (media) {
                this.info(`Founded new media to analysis. Media: ${media.name}`);
                this.ffprobeModule.analysis(yield this.storageModule.getSignedUrl(media.object_key), (err, data) => this.onAnalysisEnd(err, data, media, onComplete), settings.timeout, settings.useSystemFFprobe);
                return true;
            }
            return false;
        });
    }
    onAnalysisEnd(err, data, media, onComplete) {
        if (!err) {
            this.info(`Analysis completed with success for media ${media.name}`);
            const update = {
                video_codec: util_1.ffprobeUtil.getVideoCodec(data),
                audio_codec: util_1.ffprobeUtil.getAudioCodec(data),
                duration: util_1.ffprobeUtil.getDuration(data),
                scale: util_1.ffprobeUtil.getVideoScale(data),
                state: media_model_1.MediaStateEnum.READY,
            };
            media_model_2.mediaModel.update(update, media.id);
        }
        else {
            this.error(`Analysis completed with error for media ${media.name}. ${err}, ${data}`);
            media_model_2.mediaModel.update({
                state: media_model_1.MediaStateEnum.ANALYSIS_FAIL,
            }, media.id);
        }
        onComplete();
    }
}
exports.FfprobeTask = FfprobeTask;
exports.ffprobeTask = new FfprobeTask();
