"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mediaTaskManager = exports.MediaTaskManager = void 0;
const transcoder_task_1 = require("./transcoder-task");
const thumbnail_task_1 = require("./thumbnail-task");
const ffprobe_task_1 = require("./ffprobe-task");
class MediaTaskManager {
    constructor(ffprobe = ffprobe_task_1.ffprobeTask, thumbnail = thumbnail_task_1.thumbnailTask, transcoder = transcoder_task_1.transcoderTask) {
        this.waitTime = 30000; // 30 seconds
        this.ffprobeTask = ffprobe;
        this.thumbnailTask = thumbnail;
        this.transcoderTask = transcoder;
    }
    setSettings(settings) {
        this.settings = settings;
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!(yield this.startTask())) {
                this.wait();
            }
        });
    }
    startTask() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.settings) {
                return ((yield this.ffprobeTask.run(this.settings.probe, () => this.start())) ||
                    (yield this.thumbnailTask.run(this.settings.thumbnail, () => this.start())) ||
                    (yield this.transcoderTask.run(this.settings.transcoder, () => this.start())));
            }
            return false;
        });
    }
    wait() {
        setTimeout(() => this.start(), this.waitTime);
    }
    getTranscoderLog() {
        return this.transcoderTask.getLog();
    }
    getThumbnailLog() {
        return this.thumbnailTask.getLog();
    }
    getFfprobeLog() {
        return this.ffprobeTask.getLog();
    }
}
exports.MediaTaskManager = MediaTaskManager;
exports.mediaTaskManager = new MediaTaskManager();
