"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.serverStatusTask = exports.ServerStatusTask = void 0;
const node_os_utils_1 = __importDefault(require("node-os-utils"));
const os_1 = __importDefault(require("os"));
const check_disk_space_1 = __importDefault(require("check-disk-space"));
const media_model_1 = require("../model/media-model");
const REQUEST_MACHINE_STATE_INTERVAL = 10000;
const REQUEST_MACHINE_DISK_USAGE_INTERVAL = 1000 * 60 * 5;
const drivePath = os_1.default.platform() === 'win32' ? 'C:\\' : '/';
class ServerStatusTask {
    constructor(mediaM = media_model_1.mediaModel) {
        this.status = {
            cpu: 0,
            mem: 0,
            disk: 0,
            media: {
                size: 0,
                duration: 0,
                count_medias: 0,
                total_analysis_fail: 0,
                total_ready: 0,
                total_under_analysis: 0,
                total_upload: 0,
                total_upload_failed: 0
            }
        };
        this.mediaModel = mediaM;
    }
    start() {
        this.requestDiskUsage().then(() => {
            this.machineStatusInterval = setInterval(() => this.requestMachineStatus(), REQUEST_MACHINE_STATE_INTERVAL);
            this.diskUsageInterval = setInterval(() => this.requestDiskUsage(), REQUEST_MACHINE_DISK_USAGE_INTERVAL);
        });
    }
    stop() {
        if (this.machineStatusInterval) {
            clearInterval(this.machineStatusInterval);
        }
        if (this.diskUsageInterval) {
            clearInterval(this.diskUsageInterval);
        }
    }
    getStatus() {
        const mediaTotalStatus = this.mediaModel.getTotalDurationAndSize();
        return Object.assign(Object.assign({}, this.status), { media: mediaTotalStatus });
    }
    requestDiskUsage() {
        return __awaiter(this, void 0, void 0, function* () {
            const disk = yield (0, check_disk_space_1.default)(drivePath);
            this.status.disk = 100 * ((disk.size - disk.free) / disk.size);
        });
    }
    requestMachineStatus() {
        return __awaiter(this, void 0, void 0, function* () {
            this.status.cpu = yield node_os_utils_1.default.cpu.usage();
            this.status.mem = (yield node_os_utils_1.default.mem.info()).usedMemPercentage;
        });
    }
}
exports.ServerStatusTask = ServerStatusTask;
exports.serverStatusTask = new ServerStatusTask();
