"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.streamingTask = exports.StreamingTask = exports.PATH = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const console_module_1 = require("../module/console-module");
const util_1 = require("../util");
exports.PATH = {
    PLAYLIST_FILE_PATH: `${os_1.default.tmpdir()}/playlistFile`,
};
class StreamingTask extends console_module_1.ConsoleModule {
    getLog() {
        return super.getLog();
    }
    createMediaListFile(mediaList) {
        const port = process.env.LOOPER_PORT
            ? parseInt(process.env.LOOPER_PORT)
            : 8080;
        const rawString = "ffconcat version 1.0 \n" +
            mediaList
                .map((media) => `file 'http://localhost:${port}/media/play/${media.id}'`)
                .join("\n");
        fs_1.default.writeFileSync(exports.PATH.PLAYLIST_FILE_PATH, rawString);
    }
    createParamsList(codec, scale, outputUrl) {
        const params = [
            "-y",
            "-hide_banner",
            "-v",
            "error",
            "-re",
            "-safe",
            "0",
            "-protocol_whitelist",
            "file,http,https,tcp,tls,crypto",
            "-f",
            "concat",
            "-i",
            exports.PATH.PLAYLIST_FILE_PATH,
        ];
        if (codec) {
            params.push("-c:v", "libx264", "-c:a", "aac");
        }
        else {
            params.push("-c", "copy");
        }
        if (scale) {
            params.push("-vf", `scale=${scale}:trunc(ow/a/2)*2`);
        }
        params.push("-tune", "zerolatency", "-preset", "veryfast", "-f", "flv", outputUrl);
        return params;
    }
    run({ mediaList, codec, scale, outputUrl, useSystemFFmpeg, onTaskComplete, }) {
        this.info(`transmission started with Codec: ${codec}, Scale: ${scale}, outputUrl: ${outputUrl}`);
        this.createMediaListFile(mediaList);
        this.createWorker({
            codec,
            scale,
            outputUrl,
            useSystemFFmpeg,
            onComplete: onTaskComplete,
        });
    }
    stop() {
        if (this.controller) {
            this.info("transmission was foreced to stop by user");
            this.controller.abort();
        }
    }
    createWorker({ codec, scale, outputUrl, useSystemFFmpeg, onComplete, }) {
        this.controller = new AbortController();
        const ffmpegCommand = JSON.stringify(this.createParamsList(codec, scale, outputUrl));
        const child = (0, child_process_1.fork)(`${util_1.pathUtil.getAppRootPath()}/ffmpeg.js`, [ffmpegCommand, useSystemFFmpeg.toString()], {
            signal: this.controller.signal,
        });
        child.on("close", (code) => {
            onComplete(code);
        });
        child.on("message", (message) => {
            this.error(message);
        });
    }
}
exports.StreamingTask = StreamingTask;
exports.streamingTask = new StreamingTask();
