"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.syncWithBackupTask = exports.SyncWithBackupTask = void 0;
const sqlite_client_1 = require("../model/sqlite-client");
const log = require('../util/logger');
const constants_1 = require("../util/constants");
class SyncWithBackupTask {
    constructor(sqlite = sqlite_client_1.sqliteClient) {
        this.isRunning = false;
        this.sqliteClient = sqlite;
    }
    run() {
        if (this.isRunning)
            throw constants_1.ERROR.DB_SYNC_IS_RUNNING;
        try {
            this.isRunning = true;
            const status = {};
            const exported = this.parseDbToJson();
            status.amountMedias = this.importFromList(exported.media, constants_1.DATABASE.TABLE.MEDIA);
            status.amountOutputs = this.importFromList(exported.output, constants_1.DATABASE.TABLE.OUTPUT);
            status.amountPlaylists = this.importFromList(exported.playlist, constants_1.DATABASE.TABLE.PLAYLIST);
            return status;
        }
        catch (e) {
            log.error('Unexpected error during backup sync');
            log.error(e);
            return {
                amountMedias: 0,
                amountOutputs: 0,
                amountPlaylists: 0
            };
        }
        finally {
            this.isRunning = false;
        }
    }
    importFromList(list, table) {
        const filtered = list.filter(item => !this.sqliteClient.existsById(table, item.id));
        filtered.forEach(item => this.sqliteClient.insertOne(table, item));
        return filtered.length;
    }
    parseDbToJson() {
        const exported = {};
        const client = new sqlite_client_1.SqliteClient(constants_1.DEFAULT_DOWNLOADED_BACKUP_DB);
        exported.media = client.selectAll(constants_1.DATABASE.TABLE.MEDIA);
        exported.playlist = client.selectAll(constants_1.DATABASE.TABLE.PLAYLIST);
        exported.output = client.selectAll(constants_1.DATABASE.TABLE.OUTPUT);
        return exported;
    }
}
exports.SyncWithBackupTask = SyncWithBackupTask;
exports.syncWithBackupTask = new SyncWithBackupTask();
