"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.thumbnailTask = exports.ThumbnailTask = exports.PATH = void 0;
const os_1 = __importDefault(require("os"));
const fs_1 = __importDefault(require("fs"));
const media_model_1 = require("../model/media-model");
const console_module_1 = require("../module/console-module");
const ffmpeg_module_1 = require("../module/ffmpeg-module");
const storage_module_1 = require("../module/storage-module");
exports.PATH = {
    OUTPUT_PATH: `${os_1.default.tmpdir()}/thumbnail.jpeg`,
};
class ThumbnailTask extends console_module_1.ConsoleModule {
    constructor(mediaM = media_model_1.mediaModel, storageM = storage_module_1.storageModule, ffmpegM = ffmpeg_module_1.ffmpegModule) {
        super();
        this.mediaModel = mediaM;
        this.storageModule = storageM;
        this.ffmpegModule = ffmpegM;
    }
    run(settings, onComplete) {
        return __awaiter(this, void 0, void 0, function* () {
            if (settings.on) {
                const media = this.mediaModel.findFirstWithoutThumbnail();
                if (media) {
                    this.info(`Starting thumbnail generation for media: ${media.name}`);
                    yield this.createThumbnail(media, settings.useSystemFFmpeg, onComplete);
                    return true;
                }
            }
            return false;
        });
    }
    createThumbnail(media, useSystemFFmpeg, onComplete) {
        return __awaiter(this, void 0, void 0, function* () {
            this.ffmpegModule.thumbnail({
                input: yield this.storageModule.getSignedUrl(media.object_key),
                output: exports.PATH.OUTPUT_PATH,
                useSystemFFmpeg,
                onComplete: (err) => this.onComplete(err, media, onComplete),
            });
        });
    }
    onComplete(err, media, onComplete) {
        return __awaiter(this, void 0, void 0, function* () {
            if (err) {
                this.error(`thumbnail finished with error for media ${media.name}`);
                this.mediaModel.update({
                    thumbnail_key: "none",
                }, media.id);
                onComplete();
                return;
            }
            const thumbnail_key = `looper/${media.id}/thumbnail.jpeg`;
            try {
                yield this.storageModule.upload(thumbnail_key, `image/jpeg`, exports.PATH.OUTPUT_PATH);
                this.mediaModel.update({
                    thumbnail_key,
                }, media.id);
                this.info(`thumbnail finished for media ${media.name}`);
            }
            catch (e) {
                this.mediaModel.update({
                    thumbnail_key: "none",
                }, media.id);
                this.error(e);
            }
            finally {
                if (fs_1.default.existsSync(exports.PATH.OUTPUT_PATH)) {
                    fs_1.default.unlinkSync(exports.PATH.OUTPUT_PATH);
                }
                onComplete();
            }
        });
    }
}
exports.ThumbnailTask = ThumbnailTask;
exports.thumbnailTask = new ThumbnailTask();
