"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DATABASE = exports.DEFAULT_DOWNLOADED_BACKUP_DB = exports.DEFAULT_TASKS_SETTINGS = exports.DEFAULT_TRANSCODER_SETTINGS = exports.DEFAULT_STORAGE_SETTINGS = exports.CONTENT_TYPE = exports.ERROR = void 0;
const os_1 = __importDefault(require("os"));
class HttpError extends Error {
    constructor(status, message) {
        super(message);
        this.status = status;
    }
}
exports.ERROR = {
    UNAUTHORIZED: new HttpError(403, "unauthorized"),
    FORBIDDEN: new HttpError(403, "forbidden"),
    INVALID_BODY: new HttpError(400, "invalid_body"),
    INVALID_QUERY: new HttpError(400, "invalid_query"),
    NOT_FOUND: new HttpError(404, "not_found"),
    ACTION_DENIED: new HttpError(400, "action_denied"),
    NETWORK_ERROR: new HttpError(500, "network_error"),
    UNEXPECTED_ERROR: new HttpError(500, "unexpected_error"),
    STORAGE_NOT_CONFIGURED: new HttpError(400, "storage_not_configured"),
    UPLOAD_FAILED: new HttpError(400, "upload_failed"),
    DB_SYNC_IS_RUNNING: new HttpError(400, "db_sync_is_running"),
    EMPTY_PLAYLIST: new HttpError(400, "empty_playlist"),
    SERVER_IS_TRANSMITTING: new HttpError(400, "server_is_transmitting"),
};
exports.CONTENT_TYPE = {
    APPLICATION_OCTET_STREAM: "application/octet-stream",
};
exports.DEFAULT_STORAGE_SETTINGS = {
    provider: "AWS",
    isConfigured: false,
};
exports.DEFAULT_TRANSCODER_SETTINGS = {
    max_rate: 1500000,
    bufsize: 2250000,
    fps: 30,
    crf: 23,
    scale: "1920",
    audio_bitrate: 128000,
    audio_sample_rate: 44100,
};
exports.DEFAULT_TASKS_SETTINGS = {
    probe: {
        timeout: 60000,
        useSystemFFprobe: true,
    },
    thumbnail: {
        on: true,
        useSystemFFmpeg: true,
    },
    transcoder: {
        on: true,
        useSystemFFmpeg: true,
    },
};
exports.DEFAULT_DOWNLOADED_BACKUP_DB = `${os_1.default.tmpdir()}/downloaded-backup-db`;
exports.DATABASE = {
    DB_FOLDER_PATH: `${os_1.default.homedir()}/looper-streaming`,
    DB_FILE_NAME: `${os_1.default.homedir()}/looper-streaming/database.db`,
    DDL: `
    CREATE TABLE IF NOT EXISTS media (
        id TEXT PRIMARY KEY, 
        name TEXT NOT NULL, 
        content_type TEXT NOT NULL, 
        audio_codec TEXT, 
        video_codec TEXT,
        scale TEXT,
        duration NUMBER,
        size NUMBER,
        object_key TEXT NOT NULL, 
        state TEXT NOT NULL,
        thumbnail_key TEXT,
        send_to_transcoder INTEGER NOT NULL DEFAULT 0,
        was_transcoded INTEGER NOT NULL DEFAULT 0,
        transcoded_at INTEGER NULL,
        created_at INTEGER NOT NULL);
    CREATE TABLE IF NOT EXISTS playlist (id TEXT PRIMARY KEY, name TEXT NOT NULL, opening_media TEXT, closing_media TEXT, break_playlist TEXT,  medias TEXT);

    CREATE TABLE IF NOT EXISTS output (id TEXT PRIMARY KEY, name TEXT NOT NULL, url TEXT NOT NULL);
    
    CREATE TABLE IF NOT EXISTS version (id TEXT PRIMARY KEY);
    INSERT INTO version VALUES ('v1.0b');
    
    CREATE TABLE IF NOT EXISTS config (id TEXT PRIMARY KEY, value TEXT NOT NULL);
    INSERT INTO config VALUES ('authentication_key', 'YWRtaW4=');
    INSERT INTO config VALUES ('storage_settings', '${JSON.stringify(exports.DEFAULT_STORAGE_SETTINGS)}');
    INSERT INTO config VALUES ('transcoder_settings', '${JSON.stringify(exports.DEFAULT_TRANSCODER_SETTINGS)}');
    INSERT INTO config VALUES ('tasks_settings', '${JSON.stringify(exports.DEFAULT_TASKS_SETTINGS)}');
  `,
    TABLE: {
        MEDIA: "media",
        PLAYLIST: "playlist",
        OUTPUT: "output",
    },
};
