"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ffprobeUtil = exports.FfprobeUtil = exports.STREAM_TYPE = void 0;
exports.STREAM_TYPE = {
    AUDIO: "audio",
    VIDEO: "video",
};
class FfprobeUtil {
    getDuration(probe) {
        let duration;
        if (probe.format) {
            duration = probe.format.duration;
        }
        if (!duration) {
            const vStream = this.getVideoStream(probe);
            if (vStream) {
                duration = vStream.duration;
            }
        }
        return duration;
    }
    getVideoCodec(probe) {
        const vStream = this.getVideoStream(probe);
        return vStream ? vStream.codec_name : undefined;
    }
    getAudioCodec(probe) {
        const aStream = this.getAudioStream(probe);
        return aStream ? aStream.codec_name : undefined;
    }
    getVideoScale(probe) {
        const vStream = this.getVideoStream(probe);
        return vStream ? `${vStream.coded_height}` : undefined;
    }
    getVideoStream(probe) {
        return this.getStream(probe, exports.STREAM_TYPE.VIDEO);
    }
    getAudioStream(probe) {
        return this.getStream(probe, exports.STREAM_TYPE.AUDIO);
    }
    getStream(probe, type) {
        if (probe.streams) {
            const filtered = probe.streams.filter((stream) => stream.codec_type == type);
            return filtered && filtered.length > 0 ? filtered[0] : undefined;
        }
        return undefined;
    }
}
exports.FfprobeUtil = FfprobeUtil;
exports.ffprobeUtil = new FfprobeUtil();
