"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.S3UtilV2 = void 0;
const client_s3_1 = require("@aws-sdk/client-s3");
const s3_request_presigner_1 = require("@aws-sdk/s3-request-presigner");
const fs_1 = __importDefault(require("fs"));
const constants_1 = require("./constants");
const CHUNK_SIZE = 1024 * 1024 * 100; //100Mb
class S3UtilV2 {
    constructor(options) {
        this.options = options;
        if (!this.options.storageClass) {
            this.options.storageClass = "STANDARD";
        }
    }
    delete(objectKey) {
        const client = new client_s3_1.S3Client(this.options);
        const command = new client_s3_1.DeleteObjectCommand({
            Bucket: this.options.bucket,
            Key: objectKey,
        });
        return client.send(command);
    }
    getPresignedUrl(key, expires) {
        const client = new client_s3_1.S3Client(this.options);
        const command = new client_s3_1.GetObjectCommand({
            Bucket: this.options.bucket,
            Key: key,
        });
        return (0, s3_request_presigner_1.getSignedUrl)(client, command, { expiresIn: expires });
    }
    getUploadPresignedUrl(key, contentType) {
        const client = new client_s3_1.S3Client(this.options);
        const command = new client_s3_1.PutObjectCommand({
            Bucket: this.options.bucket,
            Key: key,
            ContentType: contentType,
        });
        return (0, s3_request_presigner_1.getSignedUrl)(client, command);
    }
    download(outputPath, Key) {
        return __awaiter(this, void 0, void 0, function* () {
            const client = new client_s3_1.S3Client(this.options);
            const command = new client_s3_1.GetObjectCommand({
                Bucket: this.options.bucket,
                Key,
            });
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                const response = yield client.send(command);
                if (response && response.Body) {
                    const file = fs_1.default.createWriteStream(outputPath);
                    const stream = response.Body;
                    stream.pipe(file).on("error", reject).on("finish", resolve);
                }
                else {
                    reject("Object not found in s3 storage!");
                }
            }));
        });
    }
    list(prefix, maxKeys, continuationToken) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const client = new client_s3_1.S3Client(this.options);
            const command = new client_s3_1.ListObjectsV2Command({
                Bucket: this.options.bucket,
                Prefix: prefix,
                MaxKeys: maxKeys,
                ContinuationToken: continuationToken,
            });
            const response = yield client.send(command);
            return {
                contents: response.Contents,
                continuationToken: response.NextContinuationToken,
                isTruncated: response.IsTruncated,
                count: (_a = response.Contents) === null || _a === void 0 ? void 0 : _a.length,
            };
        });
    }
    initMultipartUpload(objectKey, contentType) {
        const client = new client_s3_1.S3Client(this.options);
        return this.createMultipartUpload(client, objectKey, contentType);
    }
    createMultipartUpload(client, objectKey, contentType) {
        const command = new client_s3_1.CreateMultipartUploadCommand({
            Bucket: this.options.bucket,
            Key: objectKey,
            ContentType: contentType,
            StorageClass: client_s3_1.StorageClass.STANDARD,
        });
        return client.send(command);
    }
    getPresignedUploadPartUrl(uploadId, key, index) {
        const client = new client_s3_1.S3Client(this.options);
        const command = new client_s3_1.UploadPartCommand({
            Bucket: this.options.bucket,
            Key: key,
            UploadId: uploadId,
            PartNumber: index,
        });
        return (0, s3_request_presigner_1.getSignedUrl)(client, command);
    }
    completeMultipartUpload(objectKey, uploadId, uploadPartResults, client = new client_s3_1.S3Client(this.options)) {
        const command = new client_s3_1.CompleteMultipartUploadCommand({
            Bucket: this.options.bucket,
            Key: objectKey,
            MultipartUpload: {
                Parts: uploadPartResults,
            },
            UploadId: uploadId,
        });
        return client.send(command);
    }
    abortMultipartUpload(objectKey, uploadId, client = new client_s3_1.S3Client(this.options)) {
        const command = new client_s3_1.AbortMultipartUploadCommand({
            Bucket: this.options.bucket,
            Key: objectKey,
            UploadId: uploadId,
        });
        return client.send(command);
    }
    uploadMultipart(objectKey, contentType, filePath) {
        return __awaiter(this, void 0, void 0, function* () {
            let uploadId;
            try {
                const s3 = new client_s3_1.S3Client(this.options);
                const multipartCreateResult = yield this.createMultipartUpload(s3, objectKey, contentType);
                uploadId = multipartCreateResult.UploadId || "";
                const uploadPartResults = yield this.uploadChunks(s3, filePath, objectKey, uploadId);
                return yield this.completeMultipartUpload(objectKey, uploadId, uploadPartResults, s3);
            }
            catch (e) {
                try {
                    if (uploadId)
                        yield this.abortMultipartUpload(objectKey, uploadId);
                }
                catch (e2) { }
                throw constants_1.ERROR.UPLOAD_FAILED;
            }
        });
    }
    uploadChunks(s3, filePath, objectKey, uploadId) {
        return new Promise((res, rej) => __awaiter(this, void 0, void 0, function* () {
            fs_1.default.readFile(filePath, (err, buffer) => __awaiter(this, void 0, void 0, function* () {
                if (err) {
                    rej(err);
                }
                else {
                    const uploadPartResults = [];
                    let partNumber = 0;
                    for (let start = 0; start < buffer.length; start += CHUNK_SIZE) {
                        partNumber++;
                        const partParams = new client_s3_1.UploadPartCommand({
                            Body: buffer.subarray(start, start + CHUNK_SIZE),
                            PartNumber: partNumber,
                            Key: objectKey,
                            UploadId: uploadId,
                            Bucket: this.options.bucket,
                        });
                        const part = yield this.uploadChunk(s3, partParams);
                        uploadPartResults.push({
                            ETag: part.ETag,
                            PartNumber: partNumber,
                        });
                    }
                    res(uploadPartResults);
                }
            }));
        }));
    }
    uploadChunk(s3, params) {
        return s3.send(params);
    }
}
exports.S3UtilV2 = S3UtilV2;
